@@ -4,6 +4,7 @@ import json
 import copy
 from zipfile import  ZipFile
 from XmindToTestlink import preprocess
+#import preprocess
 
 class XmindToDict(object):
     def __init__(self, xmind_type = "case"):
@@ -155,10 +156,14 @@ class XmindToDict(object):
             return 0
     
     def is_case(self, in_data):
-        if len(in_data['children']['attached']) == 1: 
-            branch = in_data['children']['attached'][0]
-            if branch['title'] == "属性" or branch['title'] == "步骤":
-                return 1
+        case = 0 
+        for branch in in_data['children']['attached']:
+            if branch['title'] != "属性" or branch['title'] != "步骤":
+                case = 0
+                break
+            else:
+                case = 1
+        return case
     
     def check_suite_or_case(self, in_data):
         if "children" not in in_data.keys() or in_data['children'] == {}\
@@ -264,7 +269,13 @@ class XmindToDict(object):
                     for count in range(len(in_data['children']['attached'])):
                         attach = in_data['children']['attached'][count]
                         if isinstance(attach, dict):
-                            self.get_dict(attach, out_dict, start, pre_dict, count, req_spec, req, save_custom)
+                            if self.type == "chipreq":
+                                if not self.have_case(attach):
+                                    self.get_dict(attach, out_dict, start, pre_dict, count, req_spec, req, save_custom)
+                                else:
+                                    continue
+                            else:
+                                self.get_dict(attach, out_dict, start, pre_dict, count, req_spec, req, save_custom)
 
         if self.type == "case":
             if not self.have_case(in_data) and start == 0:
@@ -273,6 +284,8 @@ class XmindToDict(object):
                 parse_xmind(in_data, out_dict, start, pre_dict, count, req_spec, req, save_custom)
         elif self.type == "req":
             parse_xmind(in_data, out_dict, start, pre_dict, count, req_spec, req, save_custom)
+        elif self.type == "chipreq":
+            parse_xmind(in_data, out_dict, start, pre_dict, count, req_spec, req, save_custom)
 
     def check_save_custom(self, old_custom, in_data):
         for attach in in_data: 
@@ -297,7 +310,7 @@ class XmindToDict(object):
             req_dict = self.create_suite(root_name)
             self.get_req_dict(js_dict[0]['rootTopic'], req_dict)
             return root_dict, req_dict
-        elif self.type == "req":
+        elif self.type == "req" or self.type == "chipreq":
             req_name = self.get_root(js_dict)
             req_dict = self.create_suite(root_name)
             self.get_dict(js_dict[0]['rootTopic'], req_dict)
